Struct parse_js::ast::Node

source ·
pub struct Node<'a>(_);

Implementations

source

impl<'a> Node<'a>

source

pub fn try_get<'b>(self) -> Result<Ref<'b, NodeData<'a>>, BorrowError>

source

pub fn try_get_mut<'b>(self) -> Result<RefMut<'b, NodeData<'a>>, BorrowMutError>

source

pub fn get<'b>(self) -> Ref<'b, NodeData<'a>>

source

pub fn get_mut<'b>(self) -> RefMut<'b, NodeData<'a>>

source

pub fn new( session: &'a Session, scope: Scope<'a>, loc: SourceRange<'a>, stx: Syntax<'a> ) -> Node<'a>

source

pub fn error(self, typ: SyntaxErrorType) -> SyntaxError<'a>

Create an error at this node’s location. This borrows the Node and will panic if there’s an existing mutable borrow.

source

pub fn loc(self) -> SourceRange<'a>

Get the location. This borrows the Node and will panic if there’s an existing mutable borrow.

source

pub fn stx<'b>(self) -> Ref<'b, Syntax<'a>>

Get a non-mutable reference to the syntax. This non-mutably borrows the entire Node for the entire lifetime of the returned reference.

source

pub fn stx_mut<'b>(self) -> RefMut<'b, Syntax<'a>>

Get a mutable reference to the syntax. This mutably borrows the entire Node for the entire lifetime of the returned reference.

source

pub fn scope(self) -> Scope<'a>

Get the scope. This borrows the Node and will panic if there’s an existing mutable borrow.